"""fix column types

Revision ID: 4157bb294b34
Revises: 9cbb06f7c97f
Create Date: 2025-03-04 10:04:04.790842

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '4157bb294b34'
down_revision: Union[str, None] = '9cbb06f7c97f'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    if op.get_bind().dialect.name == 'sqlite':
        # SQLite-specific operations
        with op.batch_alter_table('chatbots') as batch_op:
            batch_op.alter_column('name', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=True)
            batch_op.alter_column('botname', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=True)
            batch_op.alter_column('use_personality', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_mood', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_guardrails', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_system_instructions', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_datetime', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('assign_names', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_tool_filter', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_gpu', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('skip_special_tokens', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('random_seed', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('model_version', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=True)
            batch_op.alter_column('model_type', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=True)
            batch_op.alter_column('dtype', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=True)
            batch_op.alter_column('return_result', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('do_sample', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('early_stopping', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_cache', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_backstory', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
            batch_op.alter_column('use_weather_prompt', existing_type=sa.NUMERIC(), type_=sa.Boolean(), existing_nullable=True)
        
        with op.batch_alter_table('image_filter_values') as batch_op:
            batch_op.alter_column('name', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=False)
            batch_op.alter_column('value', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=False)
            batch_op.alter_column('value_type', existing_type=sa.TEXT(), type_=sa.String(), existing_nullable=False)
            batch_op.alter_column('min_value', existing_type=sa.REAL(), type_=sa.Float(), existing_nullable=True)
            batch_op.alter_column('max_value', existing_type=sa.REAL(), type_=sa.Float(), existing_nullable=True)
    else:
        # PostgreSQL and other databases
        op.alter_column('chatbots', 'name',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'botname',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_personality',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_mood',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_guardrails',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_system_instructions',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_datetime',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'assign_names',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_tool_filter',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_gpu',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'skip_special_tokens',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'random_seed',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'model_version',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'model_type',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'dtype',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'return_result',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'do_sample',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'early_stopping',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_cache',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_backstory',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_weather_prompt',
                   existing_type=sa.NUMERIC(),
                   type_=sa.Boolean(),
                   existing_nullable=True)
        op.alter_column('image_filter_values', 'name',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=False)
        op.alter_column('image_filter_values', 'value',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=False)
        op.alter_column('image_filter_values', 'value_type',
                   existing_type=sa.TEXT(),
                   type_=sa.String(),
                   existing_nullable=False)
        op.alter_column('image_filter_values', 'min_value',
                   existing_type=sa.REAL(),
                   type_=sa.Float(),
                   existing_nullable=True)
        op.alter_column('image_filter_values', 'max_value',
                   existing_type=sa.REAL(),
                   type_=sa.Float(),
                   existing_nullable=True)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    if op.get_bind().dialect.name == 'sqlite':
        # SQLite-specific operations
        with op.batch_alter_table('image_filter_values') as batch_op:
            batch_op.alter_column('max_value', existing_type=sa.Float(), type_=sa.REAL(), existing_nullable=True)
            batch_op.alter_column('min_value', existing_type=sa.Float(), type_=sa.REAL(), existing_nullable=True)
            batch_op.alter_column('value_type', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=False)
            batch_op.alter_column('value', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=False)
            batch_op.alter_column('name', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=False)
        
        with op.batch_alter_table('chatbots') as batch_op:
            batch_op.alter_column('use_weather_prompt', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_backstory', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_cache', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('early_stopping', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('do_sample', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('return_result', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('dtype', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=True)
            batch_op.alter_column('model_type', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=True)
            batch_op.alter_column('model_version', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=True)
            batch_op.alter_column('random_seed', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('skip_special_tokens', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_gpu', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_tool_filter', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('assign_names', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_datetime', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_system_instructions', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_guardrails', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_mood', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('use_personality', existing_type=sa.Boolean(), type_=sa.NUMERIC(), existing_nullable=True)
            batch_op.alter_column('botname', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=True)
            batch_op.alter_column('name', existing_type=sa.String(), type_=sa.TEXT(), existing_nullable=True)
    else:
        # PostgreSQL and other databases
        op.alter_column('image_filter_values', 'max_value',
                   existing_type=sa.Float(),
                   type_=sa.REAL(),
                   existing_nullable=True)
        op.alter_column('image_filter_values', 'min_value',
                   existing_type=sa.Float(),
                   type_=sa.REAL(),
                   existing_nullable=True)
        op.alter_column('image_filter_values', 'value_type',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=False)
        op.alter_column('image_filter_values', 'value',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=False)
        op.alter_column('image_filter_values', 'name',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=False)
        op.alter_column('chatbots', 'use_weather_prompt',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_backstory',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_cache',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'early_stopping',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'do_sample',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'return_result',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'dtype',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'model_type',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'model_version',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'random_seed',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'skip_special_tokens',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_gpu',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_tool_filter',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'assign_names',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_datetime',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_system_instructions',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_guardrails',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_mood',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'use_personality',
                   existing_type=sa.Boolean(),
                   type_=sa.NUMERIC(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'botname',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=True)
        op.alter_column('chatbots', 'name',
                   existing_type=sa.String(),
                   type_=sa.TEXT(),
                   existing_nullable=True)
    # ### end Alembic commands ###



"""fix not null columns

Revision ID: 7802f91665d9
Revises: 27c6c721706c
Create Date: 2025-03-04 10:00:24.725742

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '7802f91665d9'
down_revision: Union[str, None] = '27c6c721706c'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    if op.get_bind().dialect.name == 'sqlite':
        # SQLite-specific operations
        with op.batch_alter_table('chatbots') as batch_op:
            batch_op.alter_column('id', existing_type=sa.INTEGER(), nullable=False, autoincrement=True)
        
        with op.batch_alter_table('image_filter_values') as batch_op:
            batch_op.alter_column('id', existing_type=sa.INTEGER(), nullable=False, autoincrement=True)
            batch_op.alter_column('name', existing_type=sa.TEXT(), nullable=False)
            batch_op.alter_column('value', existing_type=sa.TEXT(), nullable=False)
            batch_op.alter_column('value_type', existing_type=sa.TEXT(), nullable=False)
    else:
        # PostgreSQL and other databases
        op.alter_column('chatbots', 'id',
                   existing_type=sa.INTEGER(),
                   nullable=False,
                   autoincrement=True)
        op.alter_column('image_filter_values', 'id',
                   existing_type=sa.INTEGER(),
                   nullable=False,
                   autoincrement=True)
        op.alter_column('image_filter_values', 'name',
                   existing_type=sa.TEXT(),
                   nullable=False)
        op.alter_column('image_filter_values', 'value',
                   existing_type=sa.TEXT(),
                   nullable=False)
        op.alter_column('image_filter_values', 'value_type',
                   existing_type=sa.TEXT(),
                   nullable=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    if op.get_bind().dialect.name == 'sqlite':
        # SQLite-specific operations
        with op.batch_alter_table('image_filter_values') as batch_op:
            batch_op.alter_column('value_type', existing_type=sa.TEXT(), nullable=True)
            batch_op.alter_column('value', existing_type=sa.TEXT(), nullable=True)
            batch_op.alter_column('name', existing_type=sa.TEXT(), nullable=True)
            batch_op.alter_column('id', existing_type=sa.INTEGER(), nullable=True, autoincrement=True)
        
        with op.batch_alter_table('chatbots') as batch_op:
            batch_op.alter_column('id', existing_type=sa.INTEGER(), nullable=True, autoincrement=True)
    else:
        # PostgreSQL and other databases
        op.alter_column('image_filter_values', 'value_type',
                   existing_type=sa.TEXT(),
                   nullable=True)
        op.alter_column('image_filter_values', 'value',
                   existing_type=sa.TEXT(),
                   nullable=True)
        op.alter_column('image_filter_values', 'name',
                   existing_type=sa.TEXT(),
                   nullable=True)
        op.alter_column('image_filter_values', 'id',
                   existing_type=sa.INTEGER(),
                   nullable=True,
                   autoincrement=True)
        op.alter_column('chatbots', 'id',
                   existing_type=sa.INTEGER(),
                   nullable=True,
                   autoincrement=True)
    # ### end Alembic commands ###



"""add unit_system column to User

Revision ID: 68875bccab07
Revises: 5e03be0b5d05
Create Date: 2025-03-04 10:29:27.575449

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.engine.reflection import Inspector


# revision identifiers, used by Alembic.
revision: str = '68875bccab07'
down_revision: Union[str, None] = '5e03be0b5d05'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def column_exists(table_name: str, column_name: str) -> bool:
    bind = op.get_bind()
    inspector = Inspector.from_engine(bind)
    columns = [col['name'] for col in inspector.get_columns(table_name)]
    return column_name in columns


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    if not column_exists('users', 'unit_system'):
        op.add_column('users', sa.Column('unit_system', sa.String(), nullable=True))
    
    if op.get_bind().dialect.name == 'sqlite':
        op.execute("ALTER TABLE users RENAME COLUMN username TO username_old")
        op.execute("""
            ALTER TABLE users ADD COLUMN username VARCHAR(50) DEFAULT 'User' NOT NULL
        """)
        op.execute("""
            UPDATE users SET username = username_old WHERE username IS NULL
        """)
        op.execute("""
            ALTER TABLE users DROP COLUMN username_old
        """)
    else:
        op.alter_column('users', 'username',
                        existing_type=sa.VARCHAR(length=50),
                        nullable=False,
                        existing_server_default=sa.text("'User'"))
    
    if column_exists('users', 'precipitation_unit'):
        op.drop_column('users', 'precipitation_unit')
    if column_exists('users', 'wind_speed_unit'):
        op.drop_column('users', 'wind_speed_unit')
    if column_exists('users', 'temperature_unit'):
        op.drop_column('users', 'temperature_unit')
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    if not column_exists('users', 'temperature_unit'):
        op.add_column('users', sa.Column('temperature_unit', sa.VARCHAR(), nullable=True))
    if not column_exists('users', 'wind_speed_unit'):
        op.add_column('users', sa.Column('wind_speed_unit', sa.VARCHAR(), nullable=True))
    if not column_exists('users', 'precipitation_unit'):
        op.add_column('users', sa.Column('precipitation_unit', sa.VARCHAR(), nullable=True))
    
    if op.get_bind().dialect.name == 'sqlite':
        op.execute("ALTER TABLE users RENAME COLUMN username TO username_old")
        op.execute("""
            ALTER TABLE users ADD COLUMN username VARCHAR(50)
        """)
        op.execute("""
            UPDATE users SET username = username_old WHERE username IS NULL
        """)
        op.execute("""
            ALTER TABLE users DROP COLUMN username_old
        """)
    else:
        op.alter_column('users', 'username',
                        existing_type=sa.VARCHAR(length=50),
                        nullable=True,
                        existing_server_default=sa.text("'User'"))
    
    if column_exists('users', 'unit_system'):
        op.drop_column('users', 'unit_system')
    # ### end Alembic commands ###


"""Add default value to User.username

Revision ID: 5e03be0b5d05
Revises: 4157bb294b34
Create Date: 2025-03-04 10:16:06.409255

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '5e03be0b5d05'
down_revision: Union[str, None] = '4157bb294b34'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    if op.get_bind().dialect.name == 'sqlite':
        op.execute("ALTER TABLE users RENAME COLUMN username TO username_old")
        op.execute("""
            ALTER TABLE users ADD COLUMN username VARCHAR(50) DEFAULT 'User'
        """)
        op.execute("""
            UPDATE users SET username = username_old WHERE username IS NULL
        """)
        op.execute("""
            ALTER TABLE users DROP COLUMN username_old
        """)
    else:
        op.alter_column('users', 'username', server_default='User')


def downgrade() -> None:
    if op.get_bind().dialect.name == 'sqlite':
        op.execute("ALTER TABLE users RENAME COLUMN username TO username_old")
        op.execute("""
            ALTER TABLE users ADD COLUMN username VARCHAR(50)
        """)
        op.execute("""
            UPDATE users SET username = username_old WHERE username IS NULL
        """)
        op.execute("""
            ALTER TABLE users DROP COLUMN username_old
        """)
    else:
        op.alter_column('users', 'username', server_default=None)


from sqlalchemy import Column, Integer, String, Boolean, Text, BigInteger
from sqlalchemy.orm import relationship

from airunner.data.models.base import Base
from airunner.settings import DEFAULT_CHATBOT_GUARDRAILS_PROMPT, DEFAULT_CHATBOT_SYSTEM_PROMPT


class Chatbot(Base):
    __tablename__ = 'chatbots'
    id = Column(Integer, primary_key=True, autoincrement=True)
    name = Column(String, default="Chatbot")
    botname = Column(String, default="Computer")
    use_personality = Column(Boolean, default=True)
    use_mood = Column(Boolean, default=True)
    use_guardrails = Column(Boolean, default=True)
    use_system_instructions = Column(Boolean, default=True)
    use_datetime = Column(Boolean, default=True)
    assign_names = Column(Boolean, default=True)
    bot_personality = Column(Text, default="happy. He loves {{ username }}")
    prompt_template = Column(Text, default="Mistral 7B Instruct: Default Chatbot")
    use_tool_filter = Column(Boolean, default=False)
    use_gpu = Column(Boolean, default=True)
    skip_special_tokens = Column(Boolean, default=True)
    sequences = Column(Integer, default=1)
    seed = Column(BigInteger, default=42)
    random_seed = Column(Boolean, default=True)
    model_version = Column(String, default="w4ffl35/Mistral-7B-Instruct-v0.3-4bit")
    model_type = Column(String, default="llm")
    dtype = Column(String, default="4bit")
    return_result = Column(Boolean, default=True)
    guardrails_prompt = Column(Text, default=DEFAULT_CHATBOT_GUARDRAILS_PROMPT)
    system_instructions = Column(Text, default=DEFAULT_CHATBOT_SYSTEM_PROMPT)
    top_p = Column(Integer, default=900)
    min_length = Column(Integer, default=1)
    max_new_tokens = Column(Integer, default=1000)
    repetition_penalty = Column(Integer, default=100)
    do_sample = Column(Boolean, default=True)
    early_stopping = Column(Boolean, default=True)
    num_beams = Column(Integer, default=1)
    temperature = Column(Integer, default=1000)
    ngram_size = Column(Integer, default=2)
    top_k = Column(Integer, default=10)
    eta_cutoff = Column(Integer, default=10)
    num_return_sequences = Column(Integer, default=1)
    decoder_start_token_id = Column(Integer, default=None)
    use_cache = Column(Boolean, default=True)
    length_penalty = Column(Integer, default=100)
    backstory = Column(Text, default="")
    use_backstory = Column(Boolean, default=True)
    use_weather_prompt = Column(Boolean, default=False)

    target_files = relationship("TargetFiles", back_populates="chatbot")
    target_directories = relationship("TargetDirectories", back_populates="chatbot")


"""add use_weather_prompt to chatbot

Revision ID: 9cbb06f7c97f
Revises: 7802f91665d9
Create Date: 2025-03-04 10:02:18.969491

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.engine.reflection import Inspector


# revision identifiers, used by Alembic.
revision: str = '9cbb06f7c97f'
down_revision: Union[str, None] = '7802f91665d9'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    bind = op.get_bind()
    inspector = Inspector.from_engine(bind)
    columns = [col['name'] for col in inspector.get_columns('chatbots')]
    if 'use_weather_prompt' not in columns:
        op.add_column('chatbots', sa.Column('use_weather_prompt', sa.Boolean(), nullable=True))


def downgrade() -> None:
    op.drop_column('chatbots', 'use_weather_prompt')
